==> nextcloud-app-tasks-0.13.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ast.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Güei",
    "Week" : "Selmana",
    "All" : "Toos",
    "Current" : "Actual",
    "Completed" : "Completáu",
    "Tasks" : "Xeres",
    "New List" : "Nueva Llista",
    "Cancel" : "Encaboxar",
    "Save" : "Guardar",
    "An empty name is not allowed." : "Nun s'almite un nome baleru",
    "Share with users or groups" : "Compartir con usuarios y grupos",
    "can edit" : "pue editar",
    "Edit" : "Editar",
    "Download" : "Baxar",
    "Delete" : "Desaniciar",
    "Unshare" : "Dexar de compartir",
    "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
    "Hidden" : "Anubríu",
    "Visible" : "Visible",
    "Automatic" : "Automáticu",
    "Change sort order" : "Camudar orde d'ordenación",
    "Priority" : "Prioridá",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "A mano",
    "Task is completed" : "La xera ta completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n xera completada","%n xeres completaes"],
    "Tomorrow" : "Mañana",
    "Set start date" : "Afitar la fecha d'entamu",
    "Set due date" : "Afitar la data de caducidá",
    "All day" : "Tol día",
    "Task not found!" : "¡Xera non atopada!",
    "When shared show full event" : "Amosar l'eventu completu al compartir",
    "When shared show only busy" : "Amosar namás ocupáu al compartir",
    "When shared hide this event" : "Anubrir l'eventu al compartir"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ast.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Güei",
    "Week" : "Selmana",
    "All" : "Toos",
    "Current" : "Actual",
    "Completed" : "Completáu",
    "Tasks" : "Xeres",
    "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
    "Hidden" : "Anubríu",
    "Visible" : "Visible",
    "Automatic" : "Automáticu",
    "Share with users or groups" : "Compartir con usuarios y grupos",
    "Can edit" : "Can edit",
    "Edit" : "Editar",
    "Export" : "Esportar",
    "Delete" : "Desaniciar",
    "Unshare" : "Dexar de compartir",
    "Save" : "Guardar",
    "An empty name is not allowed." : "Nun s'almite un nome baleru",
    "Name" : "Nome",
    "Deleted" : "Desanicióse",
    "Restore" : "Respaldar",
    "Delete permanently" : "Desaniciar dafechu",
    "Change sort order" : "Camudar orde d'ordenación",
    "Priority" : "Prioridá",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "A mano",
    "Task is completed" : "La xera ta completada",
    "Cancel" : "Encaboxar",
    "Close" : "Zarrar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n xera completada","%n xeres completaes"],
    "Tomorrow" : "Mañana",
    "New List" : "Nueva Llista",
    "All day" : "Tol día",
    "Details" : "Detalles",
    "Notes" : "Notes",
    "Reminders" : "Recordatorios",
    "Repeat" : "Repitir",
    "When shared show full event" : "Amosar l'eventu completu al compartir",
    "When shared show only busy" : "Amosar namás ocupáu al compartir",
    "When shared hide this event" : "Anubrir l'eventu al compartir",
    "Task not found!" : "¡Xera non atopada!",
    "Set start date" : "Afitar la fecha d'entamu",
    "Set due date" : "Afitar la data de caducidá"
},
"nplurals=2; plural=(n != 1);");
